@@ -705,12 +705,12 @@ const dotAllFlagFixtures = [
 	{
 		'pattern': '.',
 		'flags': 's',
-		'expected': BMP_PATTERN
+		'expected': '[\\s\\S]'
 	},
 	{
 		'pattern': '.',
 		'flags': 'gimsy',
-		'expected': BMP_PATTERN
+		'expected': '[\\s\\S]'
 	},
 	{
 		'pattern': '.',
@@ -734,10 +734,9 @@ describe('dotAllFlag', () => {
 		it('rewrites `/' + pattern + '/' + flags + '` correctly', () => {
 			const transpiled = rewritePattern(pattern, flags, features);
 			const expected = fixture.expected;
-			assert(
-				transpiled == expected ||
-				transpiled == '(?:' + expected + ')'
-			);
+			if (transpiled != '(?:' + expected + ')') {
+				assert.strictEqual(transpiled, expected);
+			}
 		});
 	}
 });
@@ -787,23 +786,40 @@ const namedGroupFixtures = [
 		'pattern': '(?<$𐒤>a)b\\k<$𐒤>',
 		'flags': '',
 		'expected': '(a)b\\1'
+	},
+	{
+		'pattern': '(?<=a)(?<!b)(?=c)(?!d)(?:e)(?<name>f)\\k<name>',
+		'flags': '',
+		'expected': '(?<=a)(?<!b)(?=c)(?!d)(?:e)(f)\\1',
+		'expectedGroups': [
+			['name', 1]
+		],
+		'options': {
+			'lookbehind': true
+		}
 	}
 ];
 
 describe('namedGroup', () => {
 	for (const fixture of namedGroupFixtures) {
-		const pattern = fixture.pattern;
-		const flags = fixture.flags;
-		const expected = fixture.expected;
-		const expectedGroups = fixture.expectedGroups;
+		const {
+			pattern,
+			flags,
+			expected,
+			expectedGroups,
+			options = {}
+		} = fixture;
+		const groups = [];
+
+		Object.assign(options, {
+			'namedGroup': true,
+			'onNamedGroup': (name, index) => {
+				groups.push([ name, index ]);
+			}
+		});
+
 		it('rewrites `/' + pattern + '/' + flags + '` correctly', () => {
-			const groups = [];
-			const transpiled = rewritePattern(pattern, flags, {
-				'namedGroup': true,
-				'onNamedGroup': (name, index) => {
-					groups.push([ name, index ]);
-				}
-			});
+			const transpiled = rewritePattern(pattern, flags, options);
 			assert.strictEqual(transpiled, expected);
 			if (expectedGroups) {
 				assert.deepStrictEqual(groups, expectedGroups);
@@ -849,7 +865,7 @@ const lookbehindFixtures = [
 	{
 		'pattern': '(?<=.)a',
 		'flags': '',
-		'expected': '(?<=[\\0-\\t\\x0B\\f\\x0E-\\u2027\\u202A-\\uFFFF])a'
+		'expected': '(?<=.)a'
 	}
 ]
 
